@@ -19,7 +19,6 @@ namespace numpy {
 
     NumpyLoader::NumpyLoader(py::object accessor)
         : m_init(false)
-        , m_has_numeric_dtype(false)
         , m_accessor(accessor) {}
 
     NumpyLoader::~NumpyLoader() {}
@@ -31,12 +30,6 @@ namespace numpy {
         m_init = true;
     }
 
-    bool
-    NumpyLoader::has_numeric_dtype() const {
-        PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
-        return m_has_numeric_dtype;
-    }
-
     std::vector<t_dtype> 
     NumpyLoader::reconcile_dtypes(const std::vector<t_dtype>& inferred_types) const {
         PSP_VERBOSE_ASSERT(m_init, "touching uninited object");
