@@ -7,6 +7,7 @@
 #
 
 import json
+from functools import partial
 from pytest import raises
 from perspective import Table, PerspectiveError, PerspectiveManager
 
@@ -20,6 +21,11 @@ class TestPerspectiveManager(object):
         msg = json.loads(msg)
         assert msg["id"] is not None
 
+    def validate_post(self, msg, expected=None):
+        msg = json.loads(msg)
+        if expected:
+            assert msg == expected
+
     def test_manager_host_table(self):
         message = {"id": 1, "name": "table1", "cmd": "table_method", "method": "schema", "args": []}
         manager = PerspectiveManager()
@@ -68,6 +74,15 @@ class TestPerspectiveManager(object):
             "b": str
         }
 
+    def test_locked_manager_create_table(self):
+        post_callback = partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table` failed - access denied"
+        })
+        message = {"id": 1, "name": "table1", "cmd": "table", "args": [data]}
+        manager = PerspectiveManager(lock=True)
+        manager._process(message, post_callback)
+
     def test_manager_create_indexed_table(self):
         message = {"id": 1, "name": "table1", "cmd": "table", "args": [data], "options": {"index": "a"}}
         manager = PerspectiveManager()
@@ -117,7 +132,7 @@ class TestPerspectiveManager(object):
             "b": ["c"]
         }
 
-    def test_manager_host_view(self):
+    def test_manager_create_view(self):
         message = {"id": 1, "name": "view1", "cmd": "view_method", "method": "schema", "args": []}
         manager = PerspectiveManager()
         table = Table(data)
@@ -130,6 +145,19 @@ class TestPerspectiveManager(object):
             "b": str
         }
 
+    def test_locked_manager_create_view(self):
+        message = {"id": 1, "name": "view1", "cmd": "view_method", "method": "schema", "args": []}
+        manager = PerspectiveManager(lock=True)
+        table = Table(data)
+        view = table.view()
+        manager.host_table("table1", table)
+        manager.host_view("view1", view)
+        manager._process(message, self.post)
+        assert manager.get_view("view1").schema() == {
+            "a": int,
+            "b": str
+        }
+
     def test_manager_create_view_zero(self):
         message = {"id": 1, "table_name": "table1", "view_name": "view1", "cmd": "view"}
         manager = PerspectiveManager()
@@ -213,6 +241,75 @@ class TestPerspectiveManager(object):
         with raises(PerspectiveError):
             manager.clear_views(None)
 
+    # locked manager
+    def test_locked_manager_update_table(self):
+        post_callback = partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table_method.update` failed - access denied"
+        })
+        message = {"id": 1, "name": "table1", "cmd": "table_method", "method": "update", "args": [data]}
+        manager = PerspectiveManager(lock=True)
+        manager._process(message, post_callback)
+
+    def test_locked_manager_clear_table(self):
+        post_callback = partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table_method.clear` failed - access denied"
+        })
+        message = {"id": 1, "name": "table1", "cmd": "table_method", "method": "clear", "args": []}
+        manager = PerspectiveManager(lock=True)
+        manager._process(message, post_callback)
+
+    def test_locked_manager_replace_table(self):
+        post_callback = partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table_method.replace` failed - access denied"
+        })
+        message = {"id": 1, "name": "table1", "cmd": "table_method", "method": "replace", "args": [data]}
+        manager = PerspectiveManager(lock=True)
+        manager._process(message, post_callback)
+
+    def test_locked_manager_remove_table(self):
+        post_callback = partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table_method.remove` failed - access denied"
+        })
+        message = {"id": 1, "name": "table1", "cmd": "table_method", "method": "remove", "args": []}
+        manager = PerspectiveManager(lock=True)
+        manager._process(message, post_callback)
+
+    def test_locked_manager_delete_table(self):
+        post_callback = partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table_method.delete` failed - access denied"
+        })
+        message = {"id": 1, "name": "table1", "cmd": "table_method", "method": "delete", "args": []}
+        manager = PerspectiveManager(lock=True)
+        manager._process(message, post_callback)
+
+    def test_arbitary_lock_unlock_manager(self):
+        manager = PerspectiveManager(lock=True)
+        make_table_message = {"id": 1, "name": "table1", "cmd": "table", "args": [data]}
+        manager._process(make_table_message, partial(self.validate_post, expected={
+            "id": 1,
+            "error": "`table` failed - access denied"
+        }))
+        manager.unlock()
+        manager._process(make_table_message, self.post)
+        assert manager._tables["table1"].schema() == {
+            "a": int,
+            "b": str
+        }
+        update_message = {"id": 2, "name": "table1", "cmd": "table_method", "method": "update", "args": [data]}
+        manager._process(update_message, self.post)
+        assert manager._tables["table1"].size() == 6
+        manager.lock()
+        update_message_new = {"id": 3, "name": "table1", "cmd": "table_method", "method": "update", "args": [data]}
+        manager._process(update_message_new, partial(self.validate_post, expected={
+            "id": 3,
+            "error": "`table_method.update` failed - access denied"
+        }))
+
     # serialization
 
     def test_manager_to_dict(self, sentinel):
@@ -231,6 +328,22 @@ class TestPerspectiveManager(object):
         manager._process(to_dict_message, handle_to_dict)
         assert s.get() is True
 
+    def test_locked_manager_to_dict(self, sentinel):
+        s = sentinel(False)
+
+        def handle_to_dict(msg):
+            s.set(True)
+            message = json.loads(msg)
+            assert message["data"] == data
+        message = {"id": 1, "table_name": "table1", "view_name": "view1", "cmd": "view"}
+        manager = PerspectiveManager(lock=True)
+        table = Table(data)
+        manager.host_table("table1", table)
+        manager._process(message, self.post)
+        to_dict_message = {"id": 2, "name": "view1", "cmd": "view_method", "method": "to_dict"}
+        manager._process(to_dict_message, handle_to_dict)
+        assert s.get() is True
+
     def test_manager_to_dict_with_options(self, sentinel):
         s = sentinel(False)
 
